# We only compile with gcc, but other people may want other compilers.
# Set the compiler here.
%define opt_cc gcc
# Optional CFLAGS to use with the specific compiler...gcc doesn't need any,
# so uncomment and define to use
#define opt_cflags
%define opt_cxx g++
#define opt_cxxflags
%define opt_f77 gfortran
#define opt_fflags
%define opt_fc gfortran
#define opt_fcflags

%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
# Optional name suffix to use...we leave it off when compiling with gcc, but
# for other compiled versions to install side by side, it will need a
# suffix in order to keep the names from conflicting.
#define _cc_name_suffix -gcc

Name:			compat-openmpi%{?_cc_name_suffix}
Version:		1.4.3
Release:		1.2%{?dist}
Summary:		Open Message Passing Interface
Group:			Development/Libraries
License:		BSD, MIT and Romio
URL:			http://www.open-mpi.org/
# We can't use %{name} here because of _cc_name_suffix
#Source0:		http://www.open-mpi.org/software/ompi/v1.4/downloads/openmpi-%{version}.tar.bz2
# openmpi-1.4.3-RH.tar.bz2 was generated by taking the upstream 1.4.3 tarball
# and removing license-incompatible files
# (MoreDebugging/* is AML but unused in our configuration),
# (ras_loadleveler_module.c ...)
# and packaging-guidelines-incompatable (MUST use system versions of libltdl
# and libplpa, not the (formerly included ones), and also remove the generated
# Makefile.in and configure related files.
Source0:		openmpi-%{version}-RH.tar.bz2
Source1:		compat-openmpi.module.in
Source2:		macros.compat-openmpi
Source3:		macros.compat-openmpi-psm
Source4:		openmpi-1.5.3-RH.tbz
Patch0:			openmpi-1.4.3-autogen.patch
Patch1:			openmpi-1.5-dt-textrel.patch
Patch2:			openmpi-1.5.3-build.patch
BuildRoot:		%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:		flex
BuildRequires:		gcc-gfortran, libtool, numactl-devel
BuildRequires:		libibverbs-devel >= 1.1.3, opensm-devel > 3.3.0
BuildRequires:		librdmacm librdmacm-devel libibcm libibcm-devel
BuildRequires:		python libtool-ltdl-devel plpa-devel
BuildRequires:		libesmtp-devel
#sparc 64 doesnt have valgrind
%ifnarch %{sparc}
BuildRequires:          valgrind-devel
%endif
#%ifnarch ppc
#BuildRequires:		compat-dapl-devel
#%endif
%ifarch x86_64
BuildRequires:		infinipath-psm-devel
%endif
Provides:		mpi
Requires:		environment-modules
# Requires: compat-openmpi-common = %{version}-%{release}
Obsoletes:		openmpi-libs

# s390 is unlikely to have the hardware we want, and some of the -devel
# packages we require aren't available there.
# ARM has issues with a lack of "atomic primitives" so we'll exclude it as well for the moment
ExcludeArch: s390 s390x %{arm}

# Private openmpi libraries
%{?filter_setup:           
%filter_from_provides /^libmca_common_sm.so.2/d
%filter_from_provides /^libompi_dbg_msgq.so/d  
%filter_from_provides /^libompitrace.so.0/d  
%filter_from_provides /^libopen-pal.so.3/d 
%filter_from_provides /^libopen-rte.so.3/d
%filter_from_provides /^libotf.so.0/d     
%filter_from_provides /^libvt-hyb.so.0/d
%filter_from_provides /^libvt-mpi.so.0/d
%filter_from_provides /^libvt-mt.so.0/d 
%filter_from_provides /^libvt.so.0/d   
%filter_from_provides /^mca_/d      
%filter_from_requires /^libmca_common_sm.so.2/d
%filter_from_requires /^libompitrace.so.0/d    
%filter_from_requires /^libopen-pal.so.3/d 
%filter_from_requires /^libopen-rte.so.3/d
%filter_from_requires /^libotf.so.0/d     
%filter_from_requires /^libvt-hyb.so.0/d
%filter_from_requires /^libvt-mpi.so.0/d
%filter_from_requires /^libvt-mt.so.0/d 
%filter_from_requires /^libvt.so.0/d   
%filter_setup                       
}            
%global __provides_exclude_from %{_libdir}/openmpi/lib/(lib(mca|ompi|open-(pal|rte|trace)|otf|v)|openmpi/).*.so
%global __requires_exclude lib(mca|ompi|open-(pal|rte|trace)|otf|vt).*

%description
Open MPI is an open source, freely available implementation of both the 
MPI-1 and MPI-2 standards, combining technologies and resources from
several other projects (FT-MPI, LA-MPI, LAM/MPI, and PACX-MPI) in
order to build the best MPI library available.  A completely new MPI-2
compliant implementation, Open MPI offers advantages for system and
software vendors, application developers, and computer science
researchers. For more information, see http://www.open-mpi.org/ .

#%package	common
#Summary:	Common files for openmpi
#Group:		Development/Libraries
#BuildArch:	noarch

#%description common
#contains files that are common across installations of op

%package devel
Summary:        Development files for compat-openmpi
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}, gcc-gfortran
Provides:	mpi-devel

%description devel
Contains development headers and libraries for compat-openmpi

%ifarch x86_64
%package psm
Summary:		Open Message Passing Interface using InfiniPath
Group:			Development/Libraries

%description psm
Open MPI is an open source, freely available implementation of both the 
MPI-1 and MPI-2 standards, combining technologies and resources from
several other projects (FT-MPI, LA-MPI, LAM/MPI, and PACX-MPI) in
order to build the best MPI library available.  A completely new MPI-2
compliant implementation, Open MPI offers advantages for system and
software vendors, application developers, and computer science
researchers. For more information, see http://www.open-mpi.org/ .


%package psm-devel
Summary:        Development files for compat-openmpi using InfiniPath
Group:          Development/Libraries
Requires:       %{name}-psm = %{version}-%{release}, gcc-gfortran
Provides:	mpi-devel

%description psm-devel
Contains development headers and libraries for compat-openmpi using InfiniPath
%endif
# When dealing with multilib installations, aka the ability to run either
# i386 or x86_64 binaries on x86_64 machines, we install the native i386
# openmpi libs/compilers and the native x86_64 libs/compilers.  Obviously,
# on i386 you can only run i386, so you don't really need the -m32 flag
# to gcc in order to force 32 bit mode.  However, since we use the native
# i386 package to support i386 operation on x86_64, and since on x86_64
# the default is x86_64, the i386 package needs to force i386 mode.  This
# is true of all the multilib arches, hence the non-default arch (aka i386
# on x86_64) must force the non-default mode (aka 32 bit compile) in it's
# native-arch package (aka, when built on i386) so that it will work
# properly on the non-native arch as a multilib package (aka i386 installed
# on x86_64).  Just to be safe, we also force the default mode (aka 64 bit)
# in default arch packages (aka, the x86_64 package).  There are, however,
# some arches that don't support forcing *any* mode, those we just leave
# undefined.
%ifarch %{ix86} ppc sparcv9
%define mode 32
%define modeflag -m32
%endif
%ifarch ia64
%define mode 64
%endif
%ifarch x86_64 ppc64 sparc64
%define mode 64
%define modeflag -m64
%endif

# We set this to for convenience, since this is the unique dir we use for this
# particular package, version, compiler
%define namearch compat-openmpi-%{_arch}%{?_cc_name_suffix}
# Ditto for the psm build
%define namepsmarch compat-openmpi-psm-%{_arch}%{?_cc_name_suffix}

%prep
%setup -c %{name}-%{version} -q -a 4
%patch0 -p0 -b .ltversion
%patch1 -p0 -b .dt-textrel
%patch2 -p0 -b .build
%ifarch x86_64
mkdir .psm
mv * .psm
mv .psm psm
mkdir non-psm
cp -r psm/* non-psm
cd psm/openmpi-1.4.3
./autogen.sh
cd opal/libltdl
../../autogen.sh
cd ../..
cd ../openmpi-1.5.3
./autogen.sh
cd ../../non-psm
%endif
cd openmpi-1.4.3
./autogen.sh
cd opal/libltdl
../../autogen.sh
cd ../..
cd ../openmpi-1.5.3
./autogen.sh
%build
XFLAGS="-fPIC"
%ifarch x86_64
cd psm/openmpi-1.4.3
./configure --prefix=%{_libdir}/%{name}-psm --with-libnuma=/usr \
	--with-openib=/usr \
	--mandir=%{_mandir}/%{namepsmarch} \
	--includedir=%{_includedir}/%{namepsmarch} \
	--sysconfdir=%{_sysconfdir}/%{namepsmarch} \
	--enable-mpi-threads \
	--enable-openib-ibcm \
	--with-sge \
	--with-valgrind \
	--enable-memchecker \
	--with-wrapper-cflags="%{?opt_cflags} %{?modeflag}" \
	--with-wrapper-cxxflags="%{?opt_cxxflags} %{?modeflag}" \
	--with-wrapper-fflags="%{?opt_fflags} %{?modeflag}" \
	--with-wrapper-fcflags="%{?opt_fcflags} %{?modeflag}" \
	CC=%{opt_cc} CXX=%{opt_cxx} \
	LDFLAGS='-Wl,-z,noexecstack' \
	CFLAGS="%{?opt_cflags} $RPM_OPT_FLAGS $XFLAGS" \
	CXXFLAGS="%{?opt_cxxflags} $RPM_OPT_FLAGS $XFLAGS" \
	FC=%{opt_fc} FCFLAGS="%{?opt_fcflags} $RPM_OPT_FLAGS $XFLAGS" \
	F77=%{opt_f77} FFLAGS="%{?opt_fflags} $RPM_OPT_FLAGS $XFLAGS"

make %{?_smp_mflags}

cd ../openmpi-1.5.3

./configure --prefix=%{_libdir}/%{name}-psm --with-libnuma=/usr \
	--with-openib=/usr \
	--mandir=%{_mandir}/%{namepsmarch} \
	--includedir=%{_includedir}/%{namepsmarch} \
	--sysconfdir=%{_sysconfdir}/%{namepsmarch} \
	--enable-mpi-threads \
	--with-sge \
	--with-libltdl=external \
	--with-valgrind \
	--enable-memchecker \
	--with-esmtp \
	--with-wrapper-cflags="%{?opt_cflags} %{?modeflag}" \
	--with-wrapper-cxxflags="%{?opt_cxxflags} %{?modeflag}" \
	--with-wrapper-fflags="%{?opt_fflags} %{?modeflag}" \
	--with-wrapper-fcflags="%{?opt_fcflags} %{?modeflag}" \
	CC=%{opt_cc} CXX=%{opt_cxx} \
	LDFLAGS='-Wl,-z,noexecstack' \
	CFLAGS="%{?opt_cflags} $RPM_OPT_FLAGS $XFLAGS" \
	CXXFLAGS="%{?opt_cxxflags} $RPM_OPT_FLAGS $XFLAGS" \
	FC=%{opt_fc} FCFLAGS="%{?opt_fcflags} $RPM_OPT_FLAGS $XFLAGS" \
	F77=%{opt_f77} FFLAGS="%{?opt_fflags} $RPM_OPT_FLAGS $XFLAGS"

make %{?_smp_mflags}


cd ../../non-psm
%endif

cd openmpi-1.4.3
./configure --prefix=%{_libdir}/%{name} --with-libnuma=/usr \
	--with-openib=/usr \
	--mandir=%{_mandir}/%{namearch} \
	--includedir=%{_includedir}/%{namearch} \
	--sysconfdir=%{_sysconfdir}/%{namearch} \
	--enable-mpi-threads \
	--enable-openib-ibcm \
	--with-sge \
%ifnarch %{sparc}
	--with-valgrind \
	--enable-memchecker \
%endif
%ifarch x86_64
	--with-psm=no \
%endif
	--with-wrapper-cflags="%{?opt_cflags} %{?modeflag}" \
	--with-wrapper-cxxflags="%{?opt_cxxflags} %{?modeflag}" \
	--with-wrapper-fflags="%{?opt_fflags} %{?modeflag}" \
	--with-wrapper-fcflags="%{?opt_fcflags} %{?modeflag}" \
	CC=%{opt_cc} CXX=%{opt_cxx} \
	LDFLAGS='-Wl,-z,noexecstack' \
	CFLAGS="%{?opt_cflags} $RPM_OPT_FLAGS $XFLAGS" \
	CXXFLAGS="%{?opt_cxxflags} $RPM_OPT_FLAGS $XFLAGS" \
	FC=%{opt_fc} FCFLAGS="%{?opt_fcflags} $RPM_OPT_FLAGS $XFLAGS" \
	F77=%{opt_f77} FFLAGS="%{?opt_fflags} $RPM_OPT_FLAGS $XFLAGS"

make %{?_smp_mflags}

cd ../openmpi-1.5.3

./configure --prefix=%{_libdir}/%{name} --with-libnuma=/usr \
	--with-openib=/usr \
	--mandir=%{_mandir}/%{namearch} \
	--includedir=%{_includedir}/%{namearch} \
	--sysconfdir=%{_sysconfdir}/%{namearch} \
	--enable-mpi-threads \
	--with-sge \
	--with-libltdl=external \
%ifnarch %{sparc}
	--with-valgrind \
	--enable-memchecker \
%endif
%ifarch x86_64
	--with-psm=no \
%endif
	--with-esmtp \
	--with-wrapper-cflags="%{?opt_cflags} %{?modeflag}" \
	--with-wrapper-cxxflags="%{?opt_cxxflags} %{?modeflag}" \
	--with-wrapper-fflags="%{?opt_fflags} %{?modeflag}" \
	--with-wrapper-fcflags="%{?opt_fcflags} %{?modeflag}" \
	CC=%{opt_cc} CXX=%{opt_cxx} \
	LDFLAGS='-Wl,-z,noexecstack' \
	CFLAGS="%{?opt_cflags} $RPM_OPT_FLAGS $XFLAGS" \
	CXXFLAGS="%{?opt_cxxflags} $RPM_OPT_FLAGS $XFLAGS" \
	FC=%{opt_fc} FCFLAGS="%{?opt_fcflags} $RPM_OPT_FLAGS $XFLAGS" \
	F77=%{opt_f77} FFLAGS="%{?opt_fflags} $RPM_OPT_FLAGS $XFLAGS"

make %{?_smp_mflags}

%install
rm -rf %{buildroot}
%ifarch x86_64
cd psm/openmpi-1.4.3
make install DESTDIR=%{buildroot}
cd ../openmpi-1.5.3
make install DESTDIR=%{buildroot}

rm -fr %{buildroot}%{_libdir}/%{name}-psm/lib/pkgconfig
find %{buildroot}%{_libdir}/%{name}-psm/lib -name \*.la | xargs rm
find %{buildroot}%{_mandir}/%{namepsmarch} -type f | xargs gzip -9
ln -s mpicc.1.gz %{buildroot}%{_mandir}/%{namepsmarch}/man1/mpiCC.1.gz
rm -f %{buildroot}%{_mandir}/%{namepsmarch}/man1/mpiCC.1
rm -f %{buildroot}%{_mandir}/%{namepsmarch}/man1/orteCC.1*
rm -f %{buildroot}%{_libdir}/%{name}-psm/share/vampirtrace/doc/opari/lacsi01.ps.gz
mkdir %{buildroot}%{_mandir}/%{namepsmarch}/man{2,4,5,6,8,9,n}

# Make the environment-modules file
mkdir -p %{buildroot}%{_sysconfdir}/modulefiles
# Since we're doing our own substitution here, use our own definitions.
sed 's#@LIBDIR@#'%{_libdir}/%{name}-psm'#g;s#@ETCDIR@#'%{_sysconfdir}/%{namepsmarch}'#g;s#@FMODDIR@#'%{_fmoddir}/%{namepsmarch}'#g;s#@INCDIR@#'%{_includedir}/%{namepsmarch}'#g;s#@MANDIR@#'%{_mandir}/%{namepsmarch}'#g;s#@PYSITEARCH@#'%{python_sitearch}/%{name}-psm'#g;s#@COMPILER@#compat-openmpi-psm-'%{_arch}%{?_cc_name_suffix}'#g;s#@SUFFIX@#'%{?_cc_name_suffix}'_compat_openmpi_psm#g' < %SOURCE1 > %{buildroot}%{_sysconfdir}/modulefiles/%{namepsmarch}
# make the rpm config file
mkdir -p %{buildroot}/%{_sysconfdir}/rpm
cp %SOURCE3 %{buildroot}/%{_sysconfdir}/rpm/macros.%{namepsmarch}
mkdir -p %{buildroot}/%{_fmoddir}/%{namepsmarch}
mkdir -p %{buildroot}/%{python_sitearch}/compat-openmpi-psm%{?_cc_name_suffix}
cd ../../non-psm
%endif

cd openmpi-1.4.3
make install DESTDIR=%{buildroot}
cd ../openmpi-1.5.3
make install DESTDIR=%{buildroot}

rm -fr %{buildroot}%{_libdir}/%{name}/lib/pkgconfig
find %{buildroot}%{_libdir}/%{name}/lib -name \*.la | xargs rm
find %{buildroot}%{_mandir}/%{namearch} -type f | xargs gzip -9
ln -s mpicc.1.gz %{buildroot}%{_mandir}/%{namearch}/man1/mpiCC.1.gz
rm -f %{buildroot}%{_mandir}/%{namearch}/man1/mpiCC.1
rm -f %{buildroot}%{_mandir}/%{namearch}/man1/orteCC.1*
rm -f %{buildroot}%{_libdir}/%{name}/share/vampirtrace/doc/opari/lacsi01.ps.gz
mkdir %{buildroot}%{_mandir}/%{namearch}/man{2,4,5,6,8,9,n}

# Make the environment-modules file
mkdir -p %{buildroot}%{_sysconfdir}/modulefiles
# Since we're doing our own substitution here, use our own definitions.
sed 's#@LIBDIR@#'%{_libdir}/%{name}'#g;s#@ETCDIR@#'%{_sysconfdir}/%{namearch}'#g;s#@FMODDIR@#'%{_fmoddir}/%{namearch}'#g;s#@INCDIR@#'%{_includedir}/%{namearch}'#g;s#@MANDIR@#'%{_mandir}/%{namearch}'#g;s#@PYSITEARCH@#'%{python_sitearch}/%{name}'#g;s#@COMPILER@#compat-openmpi-'%{_arch}%{?_cc_name_suffix}'#g;s#@SUFFIX@#'%{?_cc_name_suffix}'_compat_openmpi#g' < %SOURCE1 > %{buildroot}%{_sysconfdir}/modulefiles/%{namearch}
# make the rpm config file
mkdir -p %{buildroot}/%{_sysconfdir}/rpm
cp %SOURCE2 %{buildroot}/%{_sysconfdir}/rpm/macros.%{namearch}
mkdir -p %{buildroot}/%{_fmoddir}/%{namearch}
mkdir -p %{buildroot}/%{python_sitearch}/compat-openmpi%{?_cc_name_suffix}



%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%dir %{_libdir}/%{name}
%dir %{_sysconfdir}/%{namearch}
%dir %{_libdir}/%{name}/bin
%dir %{_libdir}/%{name}/lib
%dir %{_libdir}/%{name}/lib/openmpi
%dir %{_mandir}/%{namearch}
%dir %{_mandir}/%{namearch}/man*
%dir %{_fmoddir}/%{namearch}
%dir %{python_sitearch}/%{name}
%config(noreplace) %{_sysconfdir}/%{namearch}/*
%{_libdir}/%{name}/bin/mpi[er]*
%{_libdir}/%{name}/bin/ompi*
#%{_libdir}/%{name}/bin/opal-*
%{_libdir}/%{name}/bin/opari
%{_libdir}/%{name}/bin/orte*
%{_libdir}/%{name}/bin/otf*
%{_libdir}/%{name}/lib/*.so.*
%{_mandir}/%{namearch}/man1/mpi[er]*
%{_mandir}/%{namearch}/man1/ompi*
#%{_mandir}/%{namearch}/man1/opal-*
%{_mandir}/%{namearch}/man1/orte*
%{_mandir}/%{namearch}/man7/ompi*
%{_mandir}/%{namearch}/man7/orte*
%{_libdir}/%{name}/lib/openmpi/*
%{_sysconfdir}/modulefiles/%{namearch}
#%files common
%dir %{_libdir}/%{name}/share
%dir %{_libdir}/%{name}/share/openmpi
%{_libdir}/%{name}/share/openmpi/doc
%{_libdir}/%{name}/share/openmpi/amca-param-sets
%{_libdir}/%{name}/share/openmpi/help*.txt
%{_libdir}/%{name}/share/openmpi/mca-btl-openib-device-params.ini

%files devel
%defattr(-,root,root,-)
%dir %{_includedir}/%{namearch}
%dir %{_libdir}/%{name}/share/vampirtrace
%{_libdir}/%{name}/bin/mpi[cCf]*
%{_libdir}/%{name}/bin/vt*
%{_libdir}/%{name}/bin/opal_*
%{_includedir}/%{namearch}/*
%{_libdir}/%{name}/lib/*.so
%{_libdir}/%{name}/lib/lib*.a
%{_libdir}/%{name}/lib/mpi.mod
%{_mandir}/%{namearch}/man1/mpi[cCf]*
%{_mandir}/%{namearch}/man1/opal_*
%{_mandir}/%{namearch}/man3/*
%{_mandir}/%{namearch}/man7/opal*
%{_libdir}/%{name}/share/openmpi/openmpi-valgrind.supp
%{_libdir}/%{name}/share/openmpi/mpi*.txt
%{_libdir}/%{name}/share/openmpi/orte*.txt
%{_libdir}/%{name}/share/vampirtrace/*
%{_sysconfdir}/rpm/macros.%{namearch}

%ifarch x86_64
%files psm
%defattr(-,root,root,-)
%dir %{_libdir}/%{name}-psm
%dir %{_sysconfdir}/%{namepsmarch}
%dir %{_libdir}/%{name}-psm/bin
%dir %{_libdir}/%{name}-psm/lib
%dir %{_libdir}/%{name}-psm/lib/openmpi
%dir %{_mandir}/%{namepsmarch}
%dir %{_mandir}/%{namepsmarch}/man*
%dir %{_fmoddir}/%{namepsmarch}
%dir %{python_sitearch}/%{name}-psm
%config(noreplace) %{_sysconfdir}/%{namepsmarch}/*
%{_libdir}/%{name}-psm/bin/mpi[er]*
%{_libdir}/%{name}-psm/bin/ompi*
#%{_libdir}/%{name}-psm/bin/opal-*
%{_libdir}/%{name}-psm/bin/opari
%{_libdir}/%{name}-psm/bin/orte*
%{_libdir}/%{name}-psm/bin/otf*
%{_libdir}/%{name}-psm/lib/*.so.*
%{_mandir}/%{namepsmarch}/man1/mpi[er]*
%{_mandir}/%{namepsmarch}/man1/ompi*
#%{_mandir}/%{namepsmarch}/man1/opal-*
%{_mandir}/%{namepsmarch}/man1/orte*
%{_mandir}/%{namepsmarch}/man7/ompi*
%{_mandir}/%{namepsmarch}/man7/orte*
%{_libdir}/%{name}-psm/lib/openmpi/*
%{_sysconfdir}/modulefiles/%{namepsmarch}
#%files common
%dir %{_libdir}/%{name}-psm/share
%dir %{_libdir}/%{name}-psm/share/openmpi
%{_libdir}/%{name}-psm/share/openmpi/doc
%{_libdir}/%{name}-psm/share/openmpi/amca-param-sets
%{_libdir}/%{name}-psm/share/openmpi/help*.txt
%{_libdir}/%{name}-psm/share/openmpi/mca-btl-openib-device-params.ini

%files psm-devel
%defattr(-,root,root,-)
%dir %{_includedir}/%{namepsmarch}
%dir %{_libdir}/%{name}-psm/share/vampirtrace
%{_libdir}/%{name}-psm/bin/mpi[cCf]*
%{_libdir}/%{name}-psm/bin/vt*
%{_libdir}/%{name}-psm/bin/opal_*
%{_includedir}/%{namepsmarch}/*
%{_libdir}/%{name}-psm/lib/*.so
%{_libdir}/%{name}-psm/lib/lib*.a
%{_libdir}/%{name}-psm/lib/mpi.mod
%{_mandir}/%{namepsmarch}/man1/mpi[cCf]*
%{_mandir}/%{namepsmarch}/man1/opal_*
%{_mandir}/%{namepsmarch}/man3/*
%{_mandir}/%{namepsmarch}/man7/opal*
%{_libdir}/%{name}-psm/share/openmpi/openmpi-valgrind.supp
%{_libdir}/%{name}-psm/share/openmpi/mpi*.txt
%{_libdir}/%{name}-psm/share/openmpi/orte*.txt
%{_libdir}/%{name}-psm/share/vampirtrace/*
%{_sysconfdir}/rpm/macros.%{namepsmarch}
%endif

%changelog
* Tue Jun 3 2014 Jay Fenlason <fenlason@redhat.com> 1.4.3-1.2
- Don't bother passing in options that the 1.4.3 configure doesn't
  understand.
- set XFLAGS on all archs, not just x86_64.
- Copy requires/provides filtering from openmpi so this will stop
  providing libotf.so.0
  Resolves: rhbz1097290

* Wed Aug 14 2013 Jay Fenlason <fenlason@redhat.com> 1.4.3-1.1
* Also include 1.5.3 libraries so users of RHEL-6.5+ can run
  programs compiled on RHEL-6.2-
  Resolves: rhbz876315

* Thu Oct 13 2011 Jay Fenlason <fenlason@redhat.com> 1.4.3-1
- New compat package to make users of openmpi-1.4 on RHEL-6 happy.
  Resolves: rhbz741009
